@@ -26,7 +26,7 @@ do_BoxPlot <- function(sample,
                        slot = "data",
                        font.size = 14,
                        font.type = "sans",
-                       rotate_x_axis_labels = TRUE,
+                       rotate_x_axis_labels = 45,
                        colors.use = NULL,
                        na.value = "grey75",
                        plot.title = NULL,
@@ -65,7 +65,6 @@ do_BoxPlot <- function(sample,
   slot <- check_and_set_slot(slot = slot)
   # Check logical parameters.
   logical_list <- list("flip" = flip,
-                       "rotate_x_axis_labels" = rotate_x_axis_labels,
                        "plot.grid" = plot.grid,
                        "order" = order,
                        "use_silhouette" = use_silhouette,
@@ -75,7 +74,8 @@ do_BoxPlot <- function(sample,
   numeric_list <- list("font.size" = font.size,
                        "outlier.alpha" = outlier.alpha,
                        "boxplot.linewidth" = boxplot.linewidth,
-                       "boxplot.width" = boxplot.width)
+                       "boxplot.width" = boxplot.width,
+                       "rotate_x_axis_labels" = rotate_x_axis_labels)
   check_type(parameters = numeric_list, required_type = "numeric", test_function = is.numeric)
   # Check character parameters.
   character_list <- list("feature" = feature,
@@ -115,7 +115,7 @@ do_BoxPlot <- function(sample,
   check_parameters(parameter = font.type, parameter_name = "font.type")
   check_parameters(parameter = legend.position, parameter_name = "legend.position")
   check_parameters(parameter = grid.type, parameter_name = "grid.type")
-
+  check_parameters(parameter = rotate_x_axis_labels, parameter_name = "rotate_x_axis_labels")
 
   if (is.null(group.by)){
     sample[["group.by"]] <- Seurat::Idents(sample)
@@ -220,9 +220,9 @@ do_BoxPlot <- function(sample,
                        axis.line.y = if (isTRUE(flip)) {ggplot2::element_line(color = "black")} else if (isFALSE(flip)) {ggplot2::element_blank()},
                        axis.text.x = ggplot2::element_text(color = "black",
                                                            face = "bold",
-                                                           angle = ifelse(isTRUE(rotate_x_axis_labels), 45, 0),
-                                                           hjust = ifelse(isTRUE(rotate_x_axis_labels), 1, 0.5),
-                                                           vjust = ifelse(isTRUE(rotate_x_axis_labels), 1, 1)),
+                                                           angle = get_axis_parameters(angle = rotate_x_axis_labels, flip = flip)[["angle"]],
+                                                           hjust = get_axis_parameters(angle = rotate_x_axis_labels, flip = flip)[["hjust"]],
+                                                           vjust = get_axis_parameters(angle = rotate_x_axis_labels, flip = flip)[["vjust"]]),
                        axis.text.y = ggplot2::element_text(color = "black", face = "bold"),
                        axis.ticks = ggplot2::element_line(color = "black"),
                        panel.grid.major = ggplot2::element_blank(),
